﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Windows.Forms.DataVisualization.Charting;

namespace VocaTest
{
    /// <summary>
    /// Displays a dialog to show statistics for the currently loaded vocs
    /// </summary>
    public partial class StatsDialog : Form
    {
        private Vocs vocs;

        private Series serieTotalVocs;
        private Series seriePassedVocs;
        private Series seriePassPercentage;
        private Series serieAveragePassPercentage;

        /// <summary>
        /// Initializes a new instance of the <see cref="StatsDialog"/> class.
        /// </summary>
        /// <param name="vocs">The vocs.</param>
        public StatsDialog(Vocs vocs)
        {
            InitializeComponent();
            this.vocs = vocs;
            this.Text = vocs.FileName + " - Statistics - " + System.Reflection.Assembly.GetExecutingAssembly().GetName().Name;
            
            serieTotalVocs = new Series("Total Nr of Vocs");
            serieTotalVocs.ChartType = (vocs.DataSet.Statistics.Count == 1) ? SeriesChartType.Column : SeriesChartType.StepLine;
            serieTotalVocs.Color = Color.Red;
            serieTotalVocs.BorderWidth = 4;

            seriePassedVocs = new Series("Passed Nr of Vocs");
            seriePassedVocs.ChartType = (vocs.DataSet.Statistics.Count == 1) ? SeriesChartType.Column : SeriesChartType.Line;
            seriePassedVocs.Color = Color.Green;
            seriePassedVocs.BorderWidth = 4;

            seriePassPercentage = new Series("Pass %");
            seriePassPercentage.ChartType = (vocs.DataSet.Statistics.Count == 1) ? SeriesChartType.Column : SeriesChartType.Line;
            seriePassPercentage.Color = Color.Gold;
            seriePassPercentage.BorderWidth = 4;

            serieAveragePassPercentage = new Series("Average Pass %");
            serieAveragePassPercentage.ChartType = (vocs.DataSet.Statistics.Count == 1) ? SeriesChartType.Column : SeriesChartType.Line;
            serieAveragePassPercentage.Color = Color.Gray;
            serieAveragePassPercentage.BorderWidth = 4;
            Double avgPassPercent = 0;

            if (vocs.DataSet.Statistics.Count > 0)
            {
                int i = 0;
                foreach (VocFileDS.StatisticsRow statRow in vocs.DataSet.Statistics)
                {
                    serieTotalVocs.Points.Add(new DataPoint(i, statRow.NumTotalVocs));
                    seriePassedVocs.Points.Add(new DataPoint(i, statRow.NumPassedVocs));

                    Double passPercent = (Double)statRow.NumPassedVocs / (Double)statRow.NumTotalVocs;
                    seriePassPercentage.Points.Add(new DataPoint(i++, passPercent*100));

                    avgPassPercent += passPercent;
                }

                avgPassPercent = avgPassPercent / vocs.DataSet.Statistics.Count;
                int avg_i = 0;
                foreach (VocFileDS.StatisticsRow statRow in vocs.DataSet.Statistics)
                {
                    serieAveragePassPercentage.Points.Add(new DataPoint(avg_i++, avgPassPercent*100));
                }
            }

            UpdateSeriesShown();
        }

        private void UpdateSeriesShown()
        {
            chartPassPercent.Series.Clear();

            if (chkShowNumTotal.Checked)
            {
                chartPassPercent.Series.Add(serieTotalVocs);
            }

            if (chkShowNumPassed.Checked)
            {
                chartPassPercent.Series.Add(seriePassedVocs);
            }

            if (chkShowPassPercent.Checked)
            {
                chartPassPercent.Series.Add(seriePassPercentage);
            }

            if (chkShowAvgPassPercent.Checked)
            {
                chartPassPercent.Series.Add(serieAveragePassPercentage);
            }

            chartPassPercent.Invalidate();
        }

        private void chkShowNumPassed_CheckedChanged(object sender, EventArgs e)
        {
            UpdateSeriesShown();
        }

        private void chkShowNumTotal_CheckedChanged(object sender, EventArgs e)
        {
            UpdateSeriesShown();
        }

        private void chkShowPassPercent_CheckedChanged(object sender, EventArgs e)
        {
            UpdateSeriesShown();
        }

        private void chkShowAvgPassPercent_CheckedChanged(object sender, EventArgs e)
        {
            UpdateSeriesShown();
        }

        private void btnClose_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void btnPrint_Click(object sender, EventArgs e)
        {
            PrintGraph();
        }

        private void btnPrintPreview_Click(object sender, EventArgs e)
        {
            PrintPreview();
        }

        private void PrintGraph()
        {
            chartPassPercent.Printing.Print(true);
        }

        private void PrintPreview()
        {
            chartPassPercent.Printing.PrintPreview();
        }

        private void printToolStripMenuItem_Click(object sender, EventArgs e)
        {
            PrintGraph();
        }

        private void printPreviewToolStripMenuItem_Click(object sender, EventArgs e)
        {
            PrintPreview();
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}
